workflowpattern

package
v1.28.0-dev Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Filter

func Filter(sequence []*WorkflowPattern, input []string) bool

Filter returns true if the workflow should be skipped per paths-ignore/branches-ignore semantics.

func Skip

func Skip(sequence []*WorkflowPattern, input []string) bool

Skip returns true if the workflow should be skipped per paths/branches semantics.

Types

type WorkflowPattern

type WorkflowPattern struct {
	// contains filtered or unexported fields
}

func CompilePatterns

func CompilePatterns(patterns ...string) ([]*WorkflowPattern, error)

Jump to